@@ -4,10 +4,23 @@ from __future__ import annotations
 
 from math import pi
 
-from .ellipsoid import Ellipsoid
-from .mathfun import atan, radians, degrees, tan, sin, cos, asinh, atanh, exp, sqrt, inf, sign
-from .utils import sanitize
 from . import rcurve
+from .ellipsoid import Ellipsoid
+from .mathfun import (
+    asinh,
+    atan,
+    atanh,
+    cos,
+    degrees,
+    exp,
+    inf,
+    radians,
+    sign,
+    sin,
+    sqrt,
+    tan,
+)
+from .utils import sanitize
 
 COS_EPS = 1e-9  # tolerance for angles near abs([90, 270])
 
@@ -197,7 +210,7 @@ def geodetic2isometric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     i = abs(coslat) <= COS_EPS
 
     try:
-        isometric_lat[i] = sign(geodetic_lat[i]) * inf  # type: ignore
+        isometric_lat[i] = sign(geodetic_lat[i]) * inf
     except TypeError:
         if i:
             isometric_lat = sign(geodetic_lat) * inf
@@ -331,7 +344,7 @@ def geodetic2conformal(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     #  compute conformal latitudes with correction for points at +90
     try:
         conformal_lat = 2 * atan(sqrt((f4 / f3) * ((f1 / f2) ** e))) - (pi / 2)
-    except ZeroDivisionError:
+    except ArithmeticError:
         conformal_lat = pi / 2
 
     return degrees(conformal_lat) if deg else conformal_lat
