@@ -5,17 +5,28 @@ Vincenty's methods for computing ground distance and reckoning
 from __future__ import annotations
 
 import logging
-from math import nan, pi
 from copy import copy
+from math import nan, pi
 
 try:
     from numpy import atleast_1d
 except ImportError:
     pass
 
-from .mathfun import sqrt, tan, sin, cos, isnan, atan, atan2, asin, radians, degrees, sign
 from .ellipsoid import Ellipsoid
-
+from .mathfun import (
+    asin,
+    atan,
+    atan2,
+    cos,
+    degrees,
+    isnan,
+    radians,
+    sign,
+    sin,
+    sqrt,
+    tan,
+)
 
 __all__ = ["vdist", "vreckon", "track2"]
 
@@ -99,7 +110,7 @@ def vdist(
     """
 
     if ell is None:
-        ell = Ellipsoid()
+        ell = Ellipsoid.from_name("wgs84")
     # %% Input check:
     try:
         Lat1 = atleast_1d(Lat1)
@@ -109,7 +120,7 @@ def vdist(
         if (abs(Lat1) > 90).any() | (abs(Lat2) > 90).any():
             raise ValueError("Input latitudes must be in [-90, 90] degrees.")
     except NameError:
-        if (abs(Lat1) > 90) | (abs(Lat2) > 90):  # type: ignore
+        if (abs(Lat1) > 90) | (abs(Lat2) > 90):
             raise ValueError("Input latitudes must be in [-90, 90] degrees.")
     # %% Supply WGS84 earth ellipsoid axis lengths in meters:
     a = ell.semimajor_axis
@@ -144,7 +155,7 @@ def vdist(
         L[L > pi] = 2 * pi - L[L > pi]
     except TypeError:
         if L > pi:
-            L = 2 * pi - L  # type: ignore
+            L = 2 * pi - L
 
     lamb = copy(L)  # NOTE: program will fail without copy!
     itercount = 0
@@ -156,7 +167,7 @@ def vdist(
             if not warninggiven:
                 logging.warning("Essentially antipodal points--precision may be reduced slightly.")
 
-            lamb = pi  # type: ignore
+            lamb = pi
             break
 
         lambdaold = copy(lamb)
@@ -179,10 +190,10 @@ def vdist(
             alpha[isnan(sinAlpha)] = 0
             alpha[(sinAlpha > 1) | (abs(sinAlpha - 1) < 1e-16)] = pi / 2
 
-        except (ZeroDivisionError, TypeError, ValueError):
+        except (ArithmeticError, TypeError, ValueError):
             try:
                 sinAlpha = cos(U1) * cos(U2) * sin(lamb) / sin(sigma)
-            except ZeroDivisionError:
+            except ArithmeticError:
                 sinAlpha = 0.0
 
             if isnan(sinAlpha):
@@ -202,7 +213,7 @@ def vdist(
         # print(f'then, lambda(21752) = {lamb[21752],20})
         # correct for convergence failure for essentially antipodal points
         try:
-            i = (lamb > pi).any()  # type: ignore
+            i = (lamb > pi).any()
         except AttributeError:
             i = lamb > pi
 
@@ -211,11 +222,11 @@ def vdist(
                 "Essentially antipodal points encountered. Precision may be reduced slightly."
             )
             warninggiven = True
-            lambdaold = pi  # type: ignore
-            lamb = pi  # type: ignore
+            lambdaold = pi
+            lamb = pi
 
         try:
-            notdone = (abs(lamb - lambdaold) > 1e-12).any()  # type: ignore
+            notdone = (abs(lamb - lambdaold) > 1e-12).any()
         except AttributeError:
             notdone = abs(lamb - lambdaold) > 1e-12
 
@@ -336,7 +347,7 @@ def vreckon(
         if (Rng < 0.0).any():
             raise ValueError("Ground distance must be positive")
     except NameError:
-        if abs(Lat1) > 90.0:  # type: ignore
+        if abs(Lat1) > 90.0:
             raise ValueError("Input lat. must be between -90 and 90 deg., inclusive.")
         if Rng < 0.0:
             raise ValueError("Ground distance must be positive")
@@ -488,7 +499,7 @@ def track2(
     """
 
     if ell is None:
-        ell = Ellipsoid()
+        ell = Ellipsoid.from_name("wgs84")
 
     if npts < 2:
         raise ValueError("npts must be greater than 1")
